@@ -160,7 +160,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                                                     if !ctx.start_transaction().await.is_ok() {
                                                         continue;
                                                     }
-                                                    let processing_result = process_handler(&internal_ctx, &mut ctx, &message.0).await;
+                                                    let processing_result = process_handler(&internal_ctx, &mut ctx, message.0.as_str().unwrap()).await;
                                                     if !processing_result.is_ok() {
                                                         if !ctx.abort_transaction().await.is_ok() {
                                                             // just log the failure to abort tx
